from setuptools import setup
print("lemme install that real quick")
setup(
    name="WOAHLIB",
    description="Woah!",
    url="https://pypi.org/project/WOAHLIB/1.1.1/",
    version="1.1.1",
    author="Woah",
    author_email="davidbeumers@gmail.com",
    license="MIT",
    packages=["woahlib"],
    zip_safe = False
)
print("yoo letsgo installed!!")



def simple_progress_bar(total,it, prefix='', length=40):
    percent = ("{0:.1f}").format(100 * (it / float(total)))
    filled_length = int(length * it // total)
    bar = f"{'#' * filled_length}{'-' * (length - filled_length)}"
    print(f'\r{prefix} |{bar}| {percent}% Complete', end='\r')

if __name__ == "__main__":
    simple_progress_bar(50,1, prefix='test', length=30)

#hehe